#!/bin/sh

set_sysfs_value()
{
    name=$1
    location=$2

    if [ "$(cat ${location})" != "${name}" ]
    then
        echo -n ${name} > ${location} \
            || echo "ERROR: pulseaudio_pre-start.sh: Failed to set ${location} to ${name}" > /dev/console
    fi
}


# Enable the use of almost the whole FIFO on all McBSP ports. Using the
# absolute maximum buffer size can cause problems: the DMA transfer apparently
# isn't fast enough, and the symptom is crackling sound. These values should be
# selected so that the buffers are as big as possible without crackling.

# McBSP2 has 1280 (1024 + 256) word long buffer on both tx and rx (rx isn't
# used). 1280 - 1200 = 80 bytes of safety margin.
set_sysfs_value 1200 /sys/devices/platform/omap-mcbsp.2/max_tx_thres

# McBSP3, 4 (and 1, 5) have 128 word long FIFO for tx and rx. 128 - 120 = 8
# bytes of safety margin.
set_sysfs_value 120 /sys/devices/platform/omap-mcbsp.3/max_tx_thres
set_sysfs_value 120 /sys/devices/platform/omap-mcbsp.3/max_rx_thres
set_sysfs_value 120 /sys/devices/platform/omap-mcbsp.4/max_tx_thres
set_sysfs_value 120 /sys/devices/platform/omap-mcbsp.4/max_rx_thres

# Disable power down delay of dfl61twl4030 to prevent crackling noises
# in some rare circumstances when playback is stopped.
set_sysfs_value 0 /sys/devices/platform/soc-audio.0/pmdown_time

# Use 5 ms dfl61dac33 power-down delay. This is for avoiding glitches when
# changing profile from dac33 playback to passthrough from dfl61twl4030 but
# still having little room for avoiding unnecessary power-ups/-downs between
# consecutive streams (although more than 50 ms is required if calling
# aplay -D hw:1 directly to device from a script).
set_sysfs_value 5 /sys/devices/platform/soc-audio.1/pmdown_time

# Enable low power playback FIFO mode of dfl61dac33.
amixer -q -Dhw:dfl61dac33 sset 'FIFO Mode' 'Mode 7 Low Power' \
 || echo "ERROR: pulseaudio_pre-start.sh: Failed to set FIFO Mode" > /dev/console

# Set initial values to 100% for controlling volumes.
# This becomes obsolete when device-restore is extended to support
# initialization of 100% sink volumes, regardless of the original mixer values.
amixer -q -Dhw:dfl61twl4030 sset "DAC2 Analog" 12 \
 || echo "ERROR: pulseaudio_pre-start.sh: Failed to set DAC2 Analog" > /dev/console
amixer -q -Dhw:dfl61dac33 sset "TPA6140A2 Headphone" 21 \
 || echo "ERROR: pulseaudio_pre-start.sh: Failed to set TPA6140A2 Headphone" > /dev/console

/bin/chown root:pulse /dev/cmt_speech
